==> qore-0.9.13.tar.bz2: qore-0.9.13/docs/modules/HttpServer/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore HttpServer Module Reference", "index.html", [
    [ "HttpServer Module", "index.html", [
      [ "HttpServer Introduction", "index.html#httpserverintro", null ],
      [ "HttpServer Module Release Notes", "index.html#http_relnotes", [
        [ "HttpServer 0.9.11", "index.html#http0911", null ],
        [ "HttpServer 0.9.5", "index.html#http095", null ],
        [ "HttpServer 0.9.4", "index.html#http094", null ],
        [ "HttpServer 0.3.13.1", "index.html#http03131", null ],
        [ "HttpServer 0.3.13", "index.html#http0313", null ],
        [ "HttpServer 0.3.12.1", "index.html#http0312", null ],
        [ "HttpServer 0.3.11.1", "index.html#http03111", null ],
        [ "HttpServer 0.3.11", "index.html#http0311", null ],
        [ "HttpServer 0.3.10", "index.html#http0310", null ],
        [ "HttpServer 0.3.9", "index.html#http039", null ],
        [ "HttpServer 0.3.8", "index.html#http038", null ],
        [ "HttpServer 0.3.7", "index.html#http037", null ],
        [ "HttpServer 0.3.6", "index.html#http036", null ],
        [ "HttpServer 0.3.5", "index.html#http035", null ],
        [ "HttpServer 0.3.4", "index.html#http034", null ],
        [ "HttpServer 0.3.3", "index.html#http033", null ],
        [ "HttpServer 0.3.2", "index.html#http032", null ],
        [ "HttpServer 0.3.1", "index.html#http031", null ],
        [ "HttpServer 0.3.0", "index.html#http030", null ],
        [ "HttpServer 0.2.9", "index.html#http029", null ],
        [ "HttpServer 0.2.8", "index.html#http028", null ],
        [ "HttpServer 0.2.7", "index.html#http027", null ],
        [ "HttpServer 0.2.6", "index.html#http026", null ],
        [ "HttpServer 0.2.5", "index.html#http025", null ],
        [ "HttpServer 0.2.4", "index.html#http024", null ],
        [ "HttpServer 0.2.3", "index.html#http023", null ],
        [ "HttpServer 0.2.2", "index.html#http022", null ],
        [ "HttpServer 0.2.1", "index.html#http021", null ],
        [ "HttpServer 0.2.0", "index.html#http020", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__cryptographic__functions.html#ga3ad2648dfb2f58c1a47d53d462bdd141",
"group__error__constants.html#ga7fe07b15810012006d4a52212c37ffb8",
"group__library__functions.html#ga62b13320abd1919d456e2cb84390b0b2",
"group__misc__functions.html#ga9034376bb44beb761d76156600b537f8",
"group__signal__constants.html#ga71be1d2281a0fa350171c12adaa88254",
"group__threading__functions.html#ga07fcdce92cacc7cea4b92504a737d7c2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.14.tar.bz2: qore-0.9.14/docs/modules/HttpServer/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore HttpServer Module Reference", "index.html", [
    [ "HttpServer Module", "index.html", [
      [ "HttpServer Introduction", "index.html#httpserverintro", null ],
      [ "HttpServer Module Release Notes", "index.html#http_relnotes", [
        [ "HttpServer 0.9.11", "index.html#http0911", null ],
        [ "HttpServer 0.9.5", "index.html#http095", null ],
        [ "HttpServer 0.9.4", "index.html#http094", null ],
        [ "HttpServer 0.3.13.1", "index.html#http03131", null ],
        [ "HttpServer 0.3.13", "index.html#http0313", null ],
        [ "HttpServer 0.3.12.1", "index.html#http0312", null ],
        [ "HttpServer 0.3.11.1", "index.html#http03111", null ],
        [ "HttpServer 0.3.11", "index.html#http0311", null ],
        [ "HttpServer 0.3.10", "index.html#http0310", null ],
        [ "HttpServer 0.3.9", "index.html#http039", null ],
        [ "HttpServer 0.3.8", "index.html#http038", null ],
        [ "HttpServer 0.3.7", "index.html#http037", null ],
        [ "HttpServer 0.3.6", "index.html#http036", null ],
        [ "HttpServer 0.3.5", "index.html#http035", null ],
        [ "HttpServer 0.3.4", "index.html#http034", null ],
        [ "HttpServer 0.3.3", "index.html#http033", null ],
        [ "HttpServer 0.3.2", "index.html#http032", null ],
        [ "HttpServer 0.3.1", "index.html#http031", null ],
        [ "HttpServer 0.3.0", "index.html#http030", null ],
        [ "HttpServer 0.2.9", "index.html#http029", null ],
        [ "HttpServer 0.2.8", "index.html#http028", null ],
        [ "HttpServer 0.2.7", "index.html#http027", null ],
        [ "HttpServer 0.2.6", "index.html#http026", null ],
        [ "HttpServer 0.2.5", "index.html#http025", null ],
        [ "HttpServer 0.2.4", "index.html#http024", null ],
        [ "HttpServer 0.2.3", "index.html#http023", null ],
        [ "HttpServer 0.2.2", "index.html#http022", null ],
        [ "HttpServer 0.2.1", "index.html#http021", null ],
        [ "HttpServer 0.2.0", "index.html#http020", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga4a67e87acc70debe7b4d841f3a0d7279",
"group__event__constants.html#gac180096573633537266011b54a4eb7c2",
"group__math__functions.html#gade650051a32f10bd32c11e43147f5c9f",
"group__parse__options.html#ga52d1e7bd71353fe0b0669e9f5a078206",
"group__system__and__build__constants.html#gac7364290dc6b93298baabb32da286c5b",
"index.html#http033"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
